@@ -1,12 +1,13 @@
 package Dist::Zilla::Plugin::ManifestSkip;
 BEGIN {
-  $Dist::Zilla::Plugin::ManifestSkip::VERSION = '4.101612';
+  $Dist::Zilla::Plugin::ManifestSkip::VERSION = '4.101900';
 }
 # ABSTRACT: decline to build files that appear in a MANIFEST.SKIP-like file
 use Moose;
 with 'Dist::Zilla::Role::FilePruner';
 
 use ExtUtils::Manifest 1.54; # public maniskip routine
+use Moose::Autobox;
 
 
 has skipfile => (is => 'ro', required => 1, default => 'MANIFEST.SKIP');
@@ -14,14 +15,17 @@ has skipfile => (is => 'ro', required => 1, default => 'MANIFEST.SKIP');
 sub prune_files {
   my ($self) = @_;
 
-  my $skip = ExtUtils::Manifest::maniskip($self->skipfile);
+  my $skipfile = $self->zilla->root->file( $self->skipfile );
+  return unless -f $skipfile;
+  my $skip = ExtUtils::Manifest::maniskip($skipfile);
 
-  my $files = $self->zilla->files;
-  @$files = grep {
-    $skip->($_->name)
-    ? do { $self->log_debug([ 'pruning %s', $_->name ]); 0 }
-    : 1
-  } @$files;
+  for my $file ($self->zilla->files->flatten) {
+    next unless $skip->($file->name);
+
+    $self->log_debug([ 'pruning %s', $file->name ]);
+
+    $self->zilla->prune_file($file);
+  }
 
   return;
 }
@@ -39,7 +43,7 @@ Dist::Zilla::Plugin::ManifestSkip - decline to build files that appear in a MANI
 
 =head1 VERSION
 
-version 4.101612
+version 4.101900
 
 =head1 DESCRIPTION
 
@@ -56,7 +60,7 @@ defaults, unsurprisingly, to F<MANIFEST.SKIP>.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
