@@ -1,5 +1,8 @@
 package Dist::Zilla::Plugin::MetaResources;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::MetaResources::VERSION = '4.101900';
+}
+
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -13,16 +16,33 @@ has resources => (
 
 sub BUILDARGS {
   my ($class, @arg) = @_;
-  my %copy = ref $arg[0] ? %{$arg[0]} : @arg;
+  my %copy = ref $arg[0] ? %{ $arg[0] } : @arg;
 
   my $zilla = delete $copy{zilla};
   my $name  = delete $copy{plugin_name};
 
+  if (exists $copy{bugtracker}) {
+    my $tracker = delete $copy{bugtracker};
+    $copy{bugtracker}{web} = $tracker;
+  }
+
+  if (exists $copy{repository}) {
+    my $repo = delete $copy{repository};
+    $copy{repository}{url} = $repo;
+  }
+
+  for my $multi (qw( bugtracker repository )) {
+    for my $key (grep { /^\Q$multi\E\./ } keys %copy) {
+      my $subkey = (split /\./, $key, 2)[1];
+      $copy{$multi}{$subkey} = delete $copy{$key};
+    }
+  }
+
   return {
-    zilla => $zilla,
+    zilla       => $zilla,
     plugin_name => $name,
     resources   => \%copy,
-  }
+  };
 }
 
 sub metadata {
@@ -44,18 +64,23 @@ Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribut
 
 =head1 VERSION
 
-version 1.100160
+version 4.101900
 
 =head1 DESCRIPTION
 
 This plugin adds resources entries to the distribution's metadata.
 
   [MetaResources]
-  homepage = http://example.com/~dude/project.asp
+  homepage          = http://example.com/~dude/project.asp
+  bugtracker.web    = http://rt.cpan.org/NoAuth/Bugs.html?Dist=Project
+  bugtracker.mailto = bug-project@rt.cpan.org
+  repository.url    = git://github.com/dude/project.git
+  repository.web    = http://github.com/dude/project
+  repository.type   = git
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
