@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::MetaTests;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::MetaTests::VERSION = '4.101900';
+}
 # ABSTRACT: common extra tests for META.yml
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -19,18 +21,18 @@ Dist::Zilla::Plugin::MetaTests - common extra tests for META.yml
 
 =head1 VERSION
 
-version 1.100160
+version 4.101900
 
 =head1 DESCRIPTION
 
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
 following files:
 
-    xt/release/meta-yaml.t - a standard Test::CPAN::Meta test
+  xt/release/meta-yaml.t - a standard Test::CPAN::Meta test
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -43,7 +45,7 @@ the same terms as the Perl 5 programming language system itself.
 
 
 __DATA__
-___[ xt/release/meta-yaml.t ]___
+___[ xt/release/distmeta.t ]___
 #!perl
 
 use Test::More;
