@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::PruneCruft;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.101900';
+}
 # ABSTRACT: prune stuff that you probably don't mean to include
 use Moose;
 use Moose::Autobox;
@@ -14,15 +16,20 @@ sub exclude_file {
   return 1 if index($file->name, $self->zilla->name . '-') == 0;
   return 1 if $file->name =~ /\A\./;
   return 1 if $file->name =~ /\A(?:Build|Makefile)\z/;
+  return 1 if $file->name eq 'MYMETA.yml';
   return;
 }
 
 sub prune_files {
   my ($self) = @_;
 
-  my $files = $self->zilla->files;
+  for my $file ($self->zilla->files->flatten) {
+    next unless $self->exclude_file($file);
 
-  @$files = $files->grep(sub { ! $self->exclude_file($_) })->flatten;
+    $self->log_debug([ 'pruning %s', $file->name ]);
+
+    $self->zilla->prune_file($file);
+  }
 
   return;
 }
@@ -40,7 +47,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 1.100160
+version 4.101900
 
 =head1 SYNOPSIS
 
@@ -57,7 +64,7 @@ but for now that exclusion exclusion mechanism has been excluded.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
