@@ -1,19 +1,18 @@
-use strict;
-use warnings;
-
 package Dist::Zilla::Role::AfterRelease;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Role::AfterRelease::VERSION = '4.101900';
+}
 # ABSTRACT: something that runs after release is mostly complete
-
 use Moose::Role;
-
 with 'Dist::Zilla::Role::Plugin';
+
+
 requires 'after_release';
 
 no Moose::Role;
 1;
 
-
+__END__
 =pod
 
 =head1 NAME
@@ -22,7 +21,7 @@ Dist::Zilla::Role::AfterRelease - something that runs after release is mostly co
 
 =head1 VERSION
 
-version 1.100160
+version 4.101900
 
 =head1 DESCRIPTION
 
@@ -31,7 +30,7 @@ once the release is done.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -42,6 +41,3 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
