@@ -1,9 +1,17 @@
 package Dist::Zilla::Role::PluginBundle;
-our $VERSION = '1.100160';
-# ABSTRACT: a bundle of plugins
+BEGIN {
+  $Dist::Zilla::Role::PluginBundle::VERSION = '4.101900';
+}
+# ABSTRACT: something that bundles a bunch of plugins
 use Moose::Role;
 
 
+sub register_component {
+  my ($class, $name, $arg, $self) = @_;
+  # ... we should register a placeholder so MetaConfig can tell us about the
+  # pluginbundle that was loaded
+}
+
 requires 'bundle_config';
 
 no Moose::Role;
@@ -14,11 +22,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Role::PluginBundle - a bundle of plugins
+Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 1.100160
+version 4.101900
 
 =head1 DESCRIPTION
 
@@ -29,7 +37,7 @@ configure the bundle.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
