@@ -2,10 +2,12 @@ use strict;
 use warnings;
 package Dist::Zilla::Util;
 BEGIN {
-  $Dist::Zilla::Util::VERSION = '4.101612';
+  $Dist::Zilla::Util::VERSION = '4.101900';
 }
 # ABSTRACT: random snippets of code that Dist::Zilla wants
 
+use File::HomeDir ();
+use Path::Class;
 use String::RewritePrefix 0.002; # better string context behavior
 
 {
@@ -35,7 +37,7 @@ use String::RewritePrefix 0.002; # better string context behavior
     }
 
     return unless $self->{in_name};
-    
+
     if (
       $event->{type} eq 'text'
       and $event->{content} =~ /^\S+\s+-+\s+(.+)$/
@@ -70,6 +72,15 @@ sub expand_config_package_name {
   return $str;
 }
 
+sub _global_config_root {
+  return dir($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
+
+  my $homedir = File::HomeDir->my_home
+    or Carp::croak("couldn't determine home directory");
+
+  return dir($homedir)->subdir('.dzil');
+}
+
 1;
 
 __END__
@@ -81,7 +92,7 @@ Dist::Zilla::Util - random snippets of code that Dist::Zilla wants
 
 =head1 VERSION
 
-version 4.101612
+version 4.101900
 
 =head1 METHODS
 
@@ -91,7 +102,7 @@ This method, I<which is likely to change or go away>, tries to guess the
 abstract of a given file, assuming that it's Perl code.  It looks for a POD
 C<=head1> section called "NAME" or a comment beginning with C<ABSTRACT:>.
 
-=head2 expand_config_package_name 
+=head2 expand_config_package_name
 
   my $pkg_name = Util->expand_config_package_name($string);
 
@@ -101,7 +112,7 @@ more information.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
